VERSION = (0, 5, 0, "f")  # following PEP 386
DEV_N = None  # for PyPi releases, set this to None


def get_version(short=False):
    version = "%s.%s" % (VERSION[0], VERSION[1])
    if short:
        return version
    if VERSION[2]:
        version = "%s.%s" % (version, VERSION[2])
    if VERSION[3] != "f":
        version = "%s%s%s" % (version, VERSION[3], VERSION[4])
        if DEV_N:
            version = "%s.dev%s" % (version, DEV_N)
    return version

__version__ = get_version()



from django.core.urlresolvers import reverse
from django.http import HttpResponse
from django.shortcuts import render_to_response
from django.db.models import get_model
from django.contrib.auth.decorators import user_passes_test


@user_passes_test(lambda u: u.is_staff)
def label_view(request, app_name, model_name, template_name="", multi=False,
               template_object_name="object"):

    try:
        object_id = request.GET.get("id", "")
        model = get_model(app_name, model_name)
        if multi:
            if object_id:
                object_id = object_id.split(",")
            model_template = "salmonella/%s/multi_%s.html" % (app_name, model_name)
            objs = model.objects.filter(id__in=object_id)
            objects = []
            for obj in objs:
                change_url = reverse("admin:%s_%s_change" % (app_name, model_name),
                                     args=[obj.id])
                obj = (obj, change_url)
                objects.append(obj)
            extra_context = {
                template_object_name: objects,
            }
        else:
            model_template = "salmonella/%s/%s.html" % (app_name, model_name)
            obj = model.objects.get(id=object_id)
            change_url = reverse("admin:%s_%s_change" % (app_name, model_name),
                                 args=[obj.id])
            obj = (obj, change_url)

            extra_context = {
                template_object_name: obj,
            }
    except model.DoesNotExist:
        return HttpResponse("")

    return render_to_response((model_template, template_name),
                              extra_context)



from django.conf.urls.defaults import *

urlpatterns = patterns('',
    url(r'^(?P<app_name>[\w-]+)/(?P<model_name>[\w-]+)/multiple/$',
        'salmonella.views.label_view',
        {
            'multi': True,
            'template_object_name': 'objects',
            'template_name': 'salmonella/multi_label.html'
        },
        name="salmonella_multi_label"),
    url(r'^(?P<app_name>[\w-]+)/(?P<model_name>[\w-]+)/$',
        'salmonella.views.label_view',
        {
            'template_name': 'salmonella/label.html'
        },
        name="salmonella_label"),
)



#!/usr/bin/env python
from setuptools import setup, find_packages

VERSION = __import__('salmonella').__version__

setup(
    name="django-salmonella",
    version=VERSION,
    author='Lincoln Loop: Seth Buntin, Yann Malet',
    author_email='info@lincolnloop.com',
    description=("raw_id_fields widget replacement that handles display of an object's "
                 "string value on change and can be overridden via a template."),
    packages=find_packages(),
    package_data={'salmonella': [
        'static/salmonella/js/*.js',
        'static/salmonella/img/*.gif',
        'templates/salmonella/*.html',
        'templates/salmonella/admin/*.html',
        'templates/salmonella/admin/widgets/*.html'
    ]},
    url="http://github.com/lincolnloop/django-salmonella/",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
